@@ -17,11 +17,11 @@ See the License for the specific language governing permissions and
 limitations under the License.
 
 :license: Apache License 2.0
-:version: 0.1.6
+:version: 0.1.9
 """
 
 # Module version
-__version_info__ = (0, 1, 6)
+__version_info__ = (0, 1, 9)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -155,13 +155,13 @@ class SimpleJSONRPCDispatcher(xmlrpcserver.SimpleXMLRPCDispatcher):
                           config=self.json_config)
             return fault.dump()
 
-        if type(request) is utils.ListType:
+        if isinstance(request, utils.ListType):
             # This SHOULD be a batch, by spec
             responses = []
             for req_entry in request:
                 # Validate the request
                 result = validate_request(req_entry, self.json_config)
-                if type(result) is Fault:
+                if isinstance(result, Fault):
                     responses.append(result.dump())
                     continue
 
@@ -176,7 +176,7 @@ class SimpleJSONRPCDispatcher(xmlrpcserver.SimpleXMLRPCDispatcher):
                 elif resp_entry is not None:
                     responses.append(resp_entry)
 
-            if len(responses) == 0:
+            if not responses:
                 # No non-None result
                 raise NoMulticallResult("No result")
 
@@ -185,7 +185,7 @@ class SimpleJSONRPCDispatcher(xmlrpcserver.SimpleXMLRPCDispatcher):
         else:
             # Single call
             result = validate_request(request, self.json_config)
-            if type(result) is Fault:
+            if isinstance(result, Fault):
                 return result.dump()
 
             # Call the method
@@ -245,18 +245,29 @@ class SimpleJSONRPCDispatcher(xmlrpcserver.SimpleXMLRPCDispatcher):
         # it is a notification
         method = request.get('method')
         params = request.get('params')
+
+        # Prepare a request-specific configuration
+        if 'jsonrpc' not in request and self.json_config.version >= 2:
+            # JSON-RPC 1.0 request on a JSON-RPC 2.0
+            # => compatibility needed
+            config = self.json_config.copy()
+            config.version = 1.0
+        else:
+            # Keep server configuration as is
+            config = self.json_config
+
         try:
             # Call the method
             if dispatch_method is not None:
                 response = dispatch_method(method, params)
             else:
-                response = self._dispatch(method, params)
+                response = self._dispatch(method, params, config)
 
         except:
             # Return a fault
             exc_type, exc_value, _ = sys.exc_info()
             fault = Fault(-32603, '{0}:{1}'.format(exc_type, exc_value),
-                          config=self.json_config)
+                          config=config)
             return fault.dump()
 
         if 'id' not in request or request['id'] in (None, ''):
@@ -266,41 +277,45 @@ class SimpleJSONRPCDispatcher(xmlrpcserver.SimpleXMLRPCDispatcher):
 
         # Prepare a JSON-RPC dictionary
         try:
+            # TODO: use a copy of the configuration, to JSON-RPC version
             return jsonrpclib.dump(response, rpcid=request['id'],
-                                   is_response=True, config=self.json_config)
+                                   is_response=True, config=config)
 
         except:
             # JSON conversion exception
             exc_type, exc_value, _ = sys.exc_info()
             fault = Fault(-32603, '{0}:{1}'.format(exc_type, exc_value),
-                          config=self.json_config)
+                          config=config)
             return fault.dump()
 
-    def _dispatch(self, method, params):
+    def _dispatch(self, method, params, config=None):
         """
         Default method resolver and caller
 
         :param method: Name of the method to call
         :param params: List of arguments to give to the method
+        :param config: Request-specific configuration
         :return: The result of the method
         """
+        config = config or self.json_config
+
         func = None
         try:
-            # Try with registered methods
+            # Look into registered methods
             func = self.funcs[method]
 
         except KeyError:
             if self.instance is not None:
                 # Try with the registered instance
-                if hasattr(self.instance, '_dispatch'):
+                try:
                     # Instance has a custom dispatcher
-                    return self.instance._dispatch(method, params)
+                    return getattr(self.instance, '_dispatch')(method, params)
 
-                else:
+                except AttributeError:
                     # Resolve the method name in the instance
                     try:
-                        func = xmlrpcserver.resolve_dotted_attribute(\
-                                                self.instance, method, True)
+                        func = xmlrpcserver.resolve_dotted_attribute(
+                            self.instance, method, True)
                     except AttributeError:
                         # Unknown method
                         pass
@@ -308,7 +323,7 @@ class SimpleJSONRPCDispatcher(xmlrpcserver.SimpleXMLRPCDispatcher):
         if func is not None:
             try:
                 # Call the method
-                if type(params) is utils.ListType:
+                if isinstance(params, utils.ListType):
                     return func(*params)
 
                 else:
@@ -317,19 +332,19 @@ class SimpleJSONRPCDispatcher(xmlrpcserver.SimpleXMLRPCDispatcher):
             except TypeError as ex:
                 # Maybe the parameters are wrong
                 return Fault(-32602, 'Invalid parameters: {0}'.format(ex),
-                             config=self.json_config)
+                             config=config)
 
             except:
                 # Method exception
                 err_lines = traceback.format_exc().splitlines()
                 trace_string = '{0} | {1}'.format(err_lines[-3], err_lines[-1])
                 return Fault(-32603, 'Server error: {0}'.format(trace_string),
-                             config=self.json_config)
+                             config=config)
 
         else:
             # Unknown method
             return Fault(-32601, 'Method {0} not supported.'.format(method),
-                         config=self.json_config)
+                         config=config)
 
 # ------------------------------------------------------------------------------
 
