@@ -48,11 +48,11 @@ appropriately.
 See https://github.com/tcalmant/jsonrpclib for more info.
 
 :license: Apache License 2.0
-:version: 0.1.8
+:version: 0.1.9
 """
 
 # Module version
-__version_info__ = (0, 1, 8)
+__version_info__ = (0, 1, 9)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -446,11 +446,11 @@ class _Method(XML_Method):
         if name == "__name__":
             return self.__name
 
-        self.__name = '%s.%s' % (self.__name, name)
+        self.__name = "{0}.{1}".format(self.__name, name)
         return self
         # The old method returned a new instance, but this seemed wasteful.
         # The only thing that changes is the name.
-        # return _Method(self.__send, "%s.%s" % (self.__name, name))
+        # return _Method(self.__send, "{0}.{1}".format(self.__name, name))
 
 class _Notify(object):
     def __init__(self, request):
@@ -485,10 +485,10 @@ class MultiCallMethod(object):
                      config=self._config)
 
     def __repr__(self):
-        return '%s' % self.request()
+        return str(self.request())
 
     def __getattr__(self, method):
-        new_method = '%s.%s' % (self.method, method)
+        new_method = "{0}.{1}".format(self.method, method)
         self.method = new_method
         return self
 
@@ -767,7 +767,7 @@ def dump(params=None, methodname=None, rpcid=None, version=None,
 
     if config.use_jsonclass:
         # Use jsonclass to convert the parameters
-        params = jsonclass.dump(params)
+        params = jsonclass.dump(params, config=config)
 
     if is_response:
         # Prepare a response dictionary
